@@ -5,8 +5,10 @@ import fabtools.require.postfix
 import fabtools.require.postgres
 import fabtools.require.mysql
 import fabtools.require.python
+import fabtools.require.redis
 import fabtools.require.service
 import fabtools.require.supervisor
+import fabtools.require.system
 import fabtools.require.users
 
 from fabtools.require.files import file
